aboutsummaryrefslogtreecommitdiffstats
path: root/core/test/app.go
diff options
context:
space:
mode:
authorMission Liao <mission.liao@dexon.org>2018-09-25 17:19:00 +0800
committerWei-Ning Huang <aitjcize@gmail.com>2018-09-25 17:19:00 +0800
commitd844c339a128322dff180a6ccc6e6b241e917546 (patch)
tree53d9b1add43a5e242a51a097be8b55048eefa1c2 /core/test/app.go
parent6c8d26d2e797e8420fc3de4b15e4c556f968aba0 (diff)
downloaddexon-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar
dexon-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.gz
dexon-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.bz2
dexon-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.lz
dexon-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.xz
dexon-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.zst
dexon-consensus-d844c339a128322dff180a6ccc6e6b241e917546.zip
Fix naming of methods (#134)
- BlockDeliver -> BlockDelivered - TotalOrderingDeliver -> TotalOrderingDelivered - WitnessAckDeliver -> WitnessAckDelivered - VerifyPayload -> VerifyPayloads
Diffstat (limited to 'core/test/app.go')
-rw-r--r--core/test/app.go16
1 files changed, 8 insertions, 8 deletions
diff --git a/core/test/app.go b/core/test/app.go
index 7a0ad97..cc2bbe6 100644
--- a/core/test/app.go
+++ b/core/test/app.go
@@ -109,8 +109,8 @@ func (app *App) PreparePayload(position types.Position) []byte {
return []byte{}
}
-// VerifyPayloads implements Application.
-func (app *App) VerifyPayloads(payloads []byte) bool {
+// VerifyPayload implements Application.
+func (app *App) VerifyPayload(payloads []byte) bool {
return true
}
@@ -126,8 +126,8 @@ func (app *App) StronglyAcked(blockHash common.Hash) {
app.Acked[blockHash] = &AppAckedRecord{When: time.Now().UTC()}
}
-// TotalOrderingDeliver implements Application interface.
-func (app *App) TotalOrderingDeliver(blockHashes common.Hashes, early bool) {
+// TotalOrderingDelivered implements Application interface.
+func (app *App) TotalOrderingDelivered(blockHashes common.Hashes, early bool) {
app.totalOrderedLock.Lock()
defer app.totalOrderedLock.Unlock()
@@ -145,8 +145,8 @@ func (app *App) TotalOrderingDeliver(blockHashes common.Hashes, early bool) {
}
}
-// BlockDeliver implements Application interface.
-func (app *App) BlockDeliver(block types.Block) {
+// BlockDelivered implements Application interface.
+func (app *App) BlockDelivered(block types.Block) {
app.deliveredLock.Lock()
defer app.deliveredLock.Unlock()
@@ -163,8 +163,8 @@ func (app *App) BlockProcessedChan() <-chan types.WitnessResult {
return app.witnessResultChan
}
-// WitnessAckDeliver implements Application interface.
-func (app *App) WitnessAckDeliver(witnessAck *types.WitnessAck) {
+// WitnessAckDelivered implements Application interface.
+func (app *App) WitnessAckDelivered(witnessAck *types.WitnessAck) {
app.witnessAckLock.Lock()
defer app.witnessAckLock.Unlock()